@@ -24,7 +24,7 @@ from uxapi.helpers import (
 class Okex(UXPatch, okex):
     def __init__(self, market_type, config=None):
         fetch_market_option = ['spot'] if market_type == 'margin' else [market_type]
-        return super().__init__(market_type, deep_extend({
+        super().__init__(market_type, deep_extend({
             'options': {
                 'fetchMarkets': fetch_market_option,
                 'defaultType': market_type,
@@ -240,7 +240,7 @@ class OkexWSHandler(WSHandler):
 
     def on_login_message(self, msg):
         if msg.get('event') == 'login':
-            self.logger.info(f'logged in')
+            self.logger.info('logged in')
             self.on_logged_in()
             raise StopIteration
         else:
